@@ -4,6 +4,8 @@ import re
 
 from halo import Halo
 from kubernetes import client, config
+from rich.table import Table
+from rich.console import Console
 
 from suite_py.lib import logger
 from suite_py.lib.handler.captainhook_handler import CaptainHook
@@ -11,17 +13,16 @@ from suite_py.lib.handler import prompt_utils
 
 
 class Aggregator:
-    def __init__(self, config, show_list, change):
+    def __init__(self, config, command):
         self._captainhook = CaptainHook(config)
-        self._show_list = show_list
-        self._change = change
+        self._command = command
 
     def run(self):
-        if self._show_list:
+        if self._command == "list":
             self._list_aggregators()
             return
 
-        if self._change:
+        if self._command == "change":
             aggregator = self._select_aggregator()
             address = prompt_utils.ask_questions_input(
                 "Insert QA url or press enter to set staging URL: ",
@@ -88,11 +89,17 @@ class Aggregator:
             logger.error("Unable to retrieve the list of aggregators.")
             return
 
-        message = "\n".join(
-            [f"* {a['name']:>20} => {a['content']:>32}" for a in aggregators.json()]
-        )
+        console = Console()
 
-        logger.info(f"\nAvailable aggregators:\n{message}\n")
+        aggregators_table = Table()
+        aggregators_table.add_column("Name", style="green")
+        aggregators_table.add_column("Address", style="white")
+
+        for a in aggregators.json():
+            aggregators_table.add_row(a["name"], a["content"])
+
+        logger.info("Available aggregators:")
+        console.print(aggregators_table)
 
     def _update_k8s_ingress_route(self, aggregator, service_name, namespace):
         try:
